@@ -1,16 +1,17 @@
 testthat::test_that("interaction_plot: lm model", {
   model <- lm_model(
     data = iris[1:4],
-    response_variable = "Sepal.Length",
-    predictor_variable = c(Sepal.Width, Petal.Width),
-    two_way_interaction_factor = c(Sepal.Width, Petal.Width)
+    response_variable = 'Sepal.Length',
+    predictor_variable = c('Sepal.Width', 'Petal.Width'),
+    two_way_interaction_factor = c('Sepal.Width', 'Petal.Width'),
+    quite = TRUE
   )
   plot <- interaction_plot(model)
   testthat::expect_false(is.null(plot))
 })
 
 testthat::test_that("interaction_plot: lme4 model", {
-  model <- lme_model(
+  suppressMessages(model <- lme_model(
     data = popular,
     response_variable = popular,
     random_effect_factors = sex,
@@ -19,13 +20,13 @@ testthat::test_that("interaction_plot: lme4 model", {
     id = class,
     use_package = "lme4",
     quite = TRUE
-  )
+  ))
   plot <- interaction_plot(model)
   testthat::expect_false(is.null(plot))
 })
 
 testthat::test_that("interaction_plot: lmerTest model", {
-  model <- lme_model(
+  suppressMessages(model <- lme_model(
     data = popular,
     response_variable = popular,
     random_effect_factors = sex,
@@ -34,14 +35,14 @@ testthat::test_that("interaction_plot: lmerTest model", {
     id = class,
     use_package = "lmerTest",
     quite = TRUE
-  )
+  ))
   plot <- interaction_plot(model)
   testthat::expect_false(is.null(plot))
 })
 
 testthat::test_that("interaction_plot: nlme model", {
   model <- lme_model(
-    data = popular,
+    data = psycModel::popular,
     response_variable = popular,
     random_effect_factors = sex,
     non_random_effect_factors = c(extrav, sex, texp),
@@ -51,7 +52,7 @@ testthat::test_that("interaction_plot: nlme model", {
     opt_control = "optim",
     quite = TRUE
   )
-  plot <- interaction_plot(model)
+  suppressWarnings(plot <- interaction_plot(model))
   testthat::expect_false(is.null(plot))
 })
 
@@ -68,7 +69,7 @@ testthat::test_that("interaction_plot: lm model", {
 })
 
 testthat::test_that("interaction_plot: lme4 model", {
-  model <- lme_model(
+  suppressMessages(model <- lme_model(
     data = popular,
     response_variable = popular,
     random_effect_factors = sex,
@@ -77,13 +78,13 @@ testthat::test_that("interaction_plot: lme4 model", {
     id = class,
     use_package = "lme4",
     quite = TRUE
-  )
+  ))
   plot <- interaction_plot(model)
   testthat::expect_false(is.null(plot))
 })
 
 testthat::test_that("interaction_plot: lmerTest model", {
-  model <- lme_model(
+  suppressMessages(model <- lme_model(
     data = popular,
     response_variable = popular,
     random_effect_factors = sex,
@@ -92,7 +93,7 @@ testthat::test_that("interaction_plot: lmerTest model", {
     id = class,
     use_package = "lmerTest",
     quite = TRUE
-  )
+  ))
   plot <- interaction_plot(model)
   testthat::expect_false(is.null(plot))
 })
@@ -109,12 +110,12 @@ testthat::test_that("interaction_plot: nlme model", {
     opt_control = "optim",
     quite = TRUE
   )
-  plot <- interaction_plot(model)
+  suppressWarnings(plot <- interaction_plot(model))
   testthat::expect_false(is.null(plot))
 })
 
 testthat::test_that("interaction_plot: nlme model", {
-  model <- lme_model(
+  suppressMessages(model <- lme_model(
     data = popular,
     response_variable = popular,
     random_effect_factors = sex,
@@ -122,7 +123,7 @@ testthat::test_that("interaction_plot: nlme model", {
     two_way_interaction_factor = c(sex, extrav, texp),
     id = class,
     quite = TRUE
-  )
+  ))
   plot <- testthat::expect_warning(interaction_plot(model))
   testthat::expect_false(is.null(plot))
 })
